%global goipath github.com/influxdata/influxdb
%global influx_usr     influxdb
%global influx_grp     influxdb
%global influx_db_dir  %{_sharedstatedir}/influxdb

Version:        1.7.7

%gometa

Name:           %{goname}
Release:        3%{?dist}
Summary:        Scalable datastore for metrics, events, and real-time analytics
License:        MIT
URL:            %{gourl}
Source0:        %{gosource}

BuildRequires:  /usr/bin/git
BuildRequires:  /usr/bin/bzr
BuildRequires:  /usr/bin/xmlto
BuildRequires:  /usr/bin/asciidoc
BuildRequires:  systemd

Requires(pre):  shadow-utils

Obsoletes:      golang-github-influxdb-influxdb <= 0.9.5.1

%{?systemd_requires}

%description
InfluxDB is an open source time series database with no external dependencies.
It's useful for recording metrics, events, and performing analytics.

Features:
    - Built-in HTTP API so you don't have to write any server side code to get
      up and running.
    - Data can be tagged, allowing very flexible querying.
    - SQL-like query language.
    - Simple to install and manage, and fast to get data in and out.
    - It aims to answer queries in real-time. That means every data point is
      indexed as it comes in and is immediately available in queries that
      should return in < 100ms.


%prep
%forgeautosetup
go mod init

# mitigates the following error:
#   go: github.com/google/go-github@v0.0.0-20181020123947-68a79fc6a32b: go.mod
#   has post-v0 module path "github.com/google/go-github/v18" at revision 68a79fc6a32b
#   go: error loading module requirements
sed -i 's#go-github v0.0.0-20181009003523-dd29b543e14c#go-github v17.0.0+incompatible#g' go.mod
#   unrecognized import path "collectd.org" 
sed -i 's#collectd.org#github.com/collectd/go-collectd#g' go.mod


%build
export GO111MODULE=on

%gobuildroot

# compile manuals
%make_build -C man

go mod download

# build binaries
export LDFLAGS="${LDFLAGS} -X main.version=%{version}"
for cmd in influx_stress influxd influx_inspect influx influx_tsm; do
    echo building ${cmd}
    %gobuild -o _bin/${cmd} %{goipath}/cmd/${cmd}
done


%install
# install manuals
%make_install -C man DESTDIR=%{buildroot}%{_prefix}

# install binaries
install -p -m 0755 -d %{buildroot}%{_bindir}
install -p -m 0755 _bin/* %{buildroot}%{_bindir}/

# install configuration file
install -p -m 0644 -D etc/config.sample.toml %{buildroot}%{_sysconfdir}/influxdb/influxdb.conf

# install service file
install -p -m 0644 -D scripts/influxdb.service %{buildroot}%{_unitdir}/influxdb.service

# db home directory
install -d -m 0755 -d %{buildroot}%{influx_db_dir}


%files
%license LICENSE
%doc README.md
%{_bindir}/influx
%{_bindir}/influx_inspect
%{_bindir}/influx_stress
%{_bindir}/influx_tsm
%{_bindir}/influxd
%{_unitdir}/influxdb.service
%dir %{_sysconfdir}/influxdb
%config(noreplace) %{_sysconfdir}/influxdb/influxdb.conf
%{_mandir}/man1/influx.1*
%{_mandir}/man1/influx_inspect.1*
%{_mandir}/man1/influx_stress.1*
%{_mandir}/man1/influx_tsm.1*
%{_mandir}/man1/influxd.1*
%{_mandir}/man1/influxd-backup.1*
%{_mandir}/man1/influxd-config.1*
%{_mandir}/man1/influxd-restore.1*
%{_mandir}/man1/influxd-run.1*
%{_mandir}/man1/influxd-version.1*
%config(noreplace) %dir %attr(0755,%{influx_usr},influxdb) %{influx_db_dir}


%pre
getent group %{influx_grp} >/dev/null || groupadd -r %{influx_grp}
getent passwd %{influx_usr} >/dev/null || \
    useradd -r -g %{influx_grp} \
               -d %{influx_db_dir} \
               -s /sbin/nologin \
               -c "influxdb database user" \
               %{influx_usr}
exit 0


%post
%systemd_post influxdb.service


%preun
%systemd_preun influxdb.service


%postun
%systemd_postun_with_restart influxdb.service


%changelog
* Fri Aug 23 2019 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 1.7.7-3
- specify main.version

* Fri Aug 23 2019 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 1.7.7-2
- Update to the latest stable version

* Mon Jan 07 2019 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 1.7.2-4
- rebuilt

* Sun Jan 06 2019 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 1.7.2-3
- rebuilt

* Sun Jan 06 2019 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 1.7.2-2
- rebuilt

* Sun Jan 06 2019 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 1.7.2-1
- First package for Fedora
